#ifndef __APCIE2032_IOMAP_H__
#define __APCIE2032_IOMAP_H__

/* registers  */
#define APCIE2032_DIGITAL_OUTPUT_REG 			0x20 /**< digital IO */
#define APCIE2032_INTERRUPT_CONTROL_REG 		0x21 /**< control diagnostic interrupts  */
#define APCIE2032_INTERRUPT_STATUS_REG 			0x22 /**< status of diagnostic */
#define APCIE2032_IRQ_STATUS_REG 				0x23 /**< state of the IRQ line */
#define APCIE2032_INTERRUPT_MSI_REG 			0x30 /**< MSI Interrupt */

#endif // __APCIE2032_IOMAP_H__
